@@ -2,16 +2,18 @@
 
 use strict;
 use warnings;
-use Log::Log4perl qw( :easy );
-use Devel::Size qw( total_size );
-
-Log::Log4perl->easy_init( $DEBUG );
 
 use lib '../lib';
 
+use Log::Log4perl qw( :easy );
+
 use Autocache qw( autocache );
 
-Autocache->initialise( filename => './lru.conf' );
+Log::Log4perl->easy_init( $DEBUG );
+
+use Devel::Size qw( total_size );
+
+Autocache->initialise( filename => './lru.conf', logger => get_logger() );
 
 autocache 'generate_data';
 
