@@ -7,7 +7,7 @@ extends 'Autocache::Strategy';
 use Autocache;
 use Time::HiRes qw( gettimeofday tv_interval );
 
-###l4p use Log::Log4perl qw( get_logger );
+use Autocache::Logger qw(get_logger);
 
 #
 # Cost-Based Strategy - only cache content that takes over a certain amount
@@ -34,49 +34,71 @@ has 'base_strategy' => (
     lazy_build => 1,
 );
 
-sub create_cache_record
+#
+# create REQ
+#
+sub create
 {
-    my ($self,$name,$normaliser,$coderef,$args,$return_type) = @_;
-###l4p     get_logger()->debug( "create_cache_record" );
+    my ($self,$req) = @_;
+    get_logger()->debug( "create" );
 
     my $t0 = [gettimeofday];
 
-    my $rec = $self->base_strategy->create_cache_record(
-        $name,$normaliser,$coderef,$args,$return_type);
+    my $rec = $self->base_strategy->create( $req );
 
     my $elapsed = tv_interval ( $t0 );
 
     $rec->{time_cost} = $elapsed * 1_000;
-    
-###l4p     get_logger()->debug( "record time_cost  : " . $rec->time_cost );
-###l4p     get_logger()->debug( "cost threshold : " . $self->cost_threshold );
+
+    get_logger()->debug( "record time_cost  : " . $rec->time_cost );
+    get_logger()->debug( "cost threshold : " . $self->cost_threshold );
 
     return $rec;
 }
 
-sub get_cache_record
+#
+# get REQ
+#
+sub get
 {
-    my ($self,$name,$normaliser,$coderef,$args,$return_type) = @_;
-###l4p     get_logger()->debug( "get_cache_record" );
+    my ($self,$req) = @_;
+    get_logger()->debug( "get" );
 
-    my $rec = $self->base_strategy->get_cache_record(
-        $name, $normaliser, $coderef, $args, $return_type );
+    my $rec = $self->base_strategy->get( $req );
 
     return $rec;
 }
 
-sub set_cache_record
+#
+# set REQ REC
+#
+sub set
 {
-    my ($self,$rec) = @_;
-###l4p     get_logger()->debug( "set_cache_record " . $rec->name );
+    my ($self,$req,$rec) = @_;
+    get_logger()->debug( "set " . $rec->name );
     # only put in cache if it has exceeded our cost threshold
     if( $rec->time_cost > $self->cost_threshold )
     {
-###l4p         get_logger()->debug( "cost threshold exceeded setting in cache" );
-        return $self->base_strategy->set_cache_record( $rec );
+        get_logger()->debug( "cost threshold exceeded setting in cache" );
+        return $self->base_strategy->set( $req, $rec );
     }
 }
 
+#
+# delete KEY
+#
+sub delete
+{
+    my ($self,$key) = @_;
+    return $self->base_strategy->delete( $key );
+}
+
+sub clear
+{
+    my ($self) = @_;
+    return $self->base_strategy->clear;
+}
+
 sub _build_base_strategy
 {
     return Autocache->singleton->get_default_strategy();
@@ -87,7 +109,7 @@ around BUILDARGS => sub
     my $orig = shift;
     my $class = shift;
 
-###l4p     get_logger()->debug( __PACKAGE__ . " - BUILDARGS" );
+    get_logger()->debug( __PACKAGE__ . " - BUILDARGS" );
 
     if( ref $_[0] )
     {
@@ -97,15 +119,15 @@ around BUILDARGS => sub
 
         if( $node = $config->get_node( 'base_strategy' ) )
         {
-###l4p             get_logger()->debug( "base strategy node found" );
+            get_logger()->debug( "base strategy node found" );
             $args{base_strategy} = Autocache->singleton->get_strategy( $node->value );
         }
-        
+
         if( $node = $config->get_node( 'cost_threshold' ) )
         {
-###l4p             get_logger()->debug( "cost threshold node found" );
+            get_logger()->debug( "cost threshold node found" );
             my $millis = $node->value;
-            
+
             unless( $millis =~ /^\d+$/ )
             {
                 if( $millis =~ /(\d+)ms/ )
@@ -124,7 +146,7 @@ around BUILDARGS => sub
 
             $args{cost_threshold} = $millis;
 
-###l4p             get_logger()->debug( sprintf 'cost threshold : %dms', $millis );
+            get_logger()->debug( sprintf 'cost threshold : %dms', $millis );
         }
 
         return $class->$orig( %args );
